@@ -3,7 +3,7 @@
 	/**
 	 * Manage roles in a database cluster
 	 *
-	 * $Id: roles.php
+	 * $Id: roles.php,v 1.13 2008/03/21 15:32:57 xzilla Exp $
 	 */
 
 	// Include application functions
@@ -33,14 +33,13 @@
 		$misc->printMsg($msg);
 
 		echo "<form action=\"roles.php\" method=\"post\">\n";
-		echo $misc->form;
 		echo "<table>\n";
-		echo "\t<tr>\n\t\t<th class=\"data left required\" width=\"130\">{$lang['strrolename']}</th>\n";
-		echo "\t\t<td class=\"data1\"><input size=\"15\" maxlength=\"15\" name=\"formRolename\" value=\"", htmlspecialchars($_POST['formRolename']), "\" /></td>\n\t</tr>\n";
+		echo "\t<tr>\n\t\t<th class=\"data left required\" style=\"width: 130px\">{$lang['strname']}</th>\n";
+		echo "\t\t<td class=\"data1\"><input size=\"15\" maxlength=\"{$data->_maxNameLen}\" name=\"formRolename\" value=\"", htmlspecialchars($_POST['formRolename']), "\" /></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strpassword']}</th>\n";
-		echo "\t\t<td class=\"data1\"><input size=\"15\" maxlength=\"32\" type=\"password\" name=\"formPassword\" value=\"", htmlspecialchars($_POST['formPassword']), "\" /></td>\n\t</tr>\n";
+		echo "\t\t<td class=\"data1\"><input size=\"15\" type=\"password\" name=\"formPassword\" value=\"", htmlspecialchars($_POST['formPassword']), "\" /></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strconfirm']}</th>\n";
-		echo "\t\t<td class=\"data1\"><input size=\"15\" maxlength=\"32\" type=\"password\" name=\"formConfirm\" value=\"", htmlspecialchars($_POST['formConfirm']), "\" /></td>\n\t</tr>\n";
+		echo "\t\t<td class=\"data1\"><input size=\"15\" type=\"password\" name=\"formConfirm\" value=\"", htmlspecialchars($_POST['formConfirm']), "\" /></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left\"><label for=\"formSuper\">{$lang['strsuper']}</label></th>\n";
 		echo "\t\t<td class=\"data1\"><input type=\"checkbox\" id=\"formSuper\" name=\"formSuper\"", 
 			(isset($_POST['formSuper'])) ? ' checked="checked"' : '', " /></td>\n\t</tr>\n";
@@ -48,9 +47,9 @@
 		echo "\t\t<td class=\"data1\"><input type=\"checkbox\" id=\"formCreateDB\" name=\"formCreateDB\"", 
 			(isset($_POST['formCreateDB'])) ? ' checked="checked"' : '', " /></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left\"><label for=\"formCreateRole\">{$lang['strcancreaterole']}</label></th>\n";
-		echo "\t\t<td class=\"data1\"><input type=\"checkbox\" id=\"formCreateDB\" name=\"formCreateRole\"", 
+		echo "\t\t<td class=\"data1\"><input type=\"checkbox\" id=\"formCreateRole\" name=\"formCreateRole\"", 
 			(isset($_POST['formCreateRole'])) ? ' checked="checked"' : '', " /></td>\n\t</tr>\n";
-		echo "\t<tr>\n\t\t<th class=\"data left\"><label for=\"formCreateDB\">{$lang['strinheritsprivs']}</label></th>\n";
+		echo "\t<tr>\n\t\t<th class=\"data left\"><label for=\"formInherits\">{$lang['strinheritsprivs']}</label></th>\n";
 		echo "\t\t<td class=\"data1\"><input type=\"checkbox\" id=\"formInherits\" name=\"formInherits\"", 
 			(isset($_POST['formInherits'])) ? ' checked="checked"' : '', " /></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left\"><label for=\"formCanLogin\">{$lang['strcanlogin']}</label></th>\n";
@@ -59,7 +58,7 @@
 		echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strconnlimit']}</th>\n";
 		echo "\t\t<td class=\"data1\"><input size=\"4\" name=\"formConnLimit\" value=\"", htmlspecialchars($_POST['formConnLimit']), "\" /></td>\n\t</tr>\n";
 		echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strexpires']}</th>\n";
-		echo "\t\t<td class=\"data1\"><input size=\"23\" maxlength=\"60\" name=\"formExpires\" value=\"", htmlspecialchars($_POST['formExpires']), "\" /></td>\n\t</tr>\n";
+		echo "\t\t<td class=\"data1\"><input size=\"23\" name=\"formExpires\" value=\"", htmlspecialchars($_POST['formExpires']), "\" /></td>\n\t</tr>\n";
 		
 		$roles = $data->getRoles();
 		if ($roles->recordCount() > 0) {
@@ -67,7 +66,7 @@
 			echo "\t\t<td class=\"data\">\n";
 			echo "\t\t\t<select name=\"memberof[]\" multiple=\"multiple\" size=\"", min(20, $roles->recordCount()), "\">\n";
 			while (!$roles->EOF) {
-				$rolename = $roles->f['rolname'];
+				$rolename = $roles->fields['rolname'];
 				echo "\t\t\t\t<option value=\"{$rolename}\"",
 				(in_array($rolename, $_POST['memberof']) ? ' selected="selected"' : ''), ">", $misc->printVal($rolename), "</option>\n";
 				$roles->moveNext();
@@ -80,7 +79,7 @@
 			echo "\t\t<td class=\"data\">\n";
 			echo "\t\t\t<select name=\"members[]\" multiple=\"multiple\" size=\"", min(20, $roles->recordCount()), "\">\n";
 			while (!$roles->EOF) {
-				$rolename = $roles->f['rolname'];
+				$rolename = $roles->fields['rolname'];
 				echo "\t\t\t\t<option value=\"{$rolename}\"",
 				(in_array($rolename, $_POST['members']) ? ' selected="selected"' : ''), ">", $misc->printVal($rolename), "</option>\n";
 				$roles->moveNext();
@@ -93,7 +92,7 @@
 			echo "\t\t<td class=\"data\">\n";
 			echo "\t\t\t<select name=\"adminmembers[]\" multiple=\"multiple\" size=\"", min(20, $roles->recordCount()), "\">\n";
 			while (!$roles->EOF) {
-				$rolename = $roles->f['rolname'];
+				$rolename = $roles->fields['rolname'];
 				echo "\t\t\t\t<option value=\"{$rolename}\"",
 				(in_array($rolename, $_POST['adminmembers']) ? ' selected="selected"' : ''), ">", $misc->printVal($rolename), "</option>\n";
 				$roles->moveNext();
@@ -104,6 +103,7 @@
 		
 		echo "</table>\n";
 		echo "<p><input type=\"hidden\" name=\"action\" value=\"save_create\" />\n";
+		echo $misc->form;
 		echo "<input type=\"submit\" name=\"create\" value=\"{$lang['strcreate']}\" />\n";
 		echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 		echo "</form>\n";
@@ -144,7 +144,7 @@
 		global $lang;
 
 		$misc->printTrail('role');
-		$misc->printTitle($lang['stralterrole'],'pg.role.alter');
+		$misc->printTitle($lang['stralter'],'pg.role.alter');
 		$misc->printMsg($msg);
 				
 		$roledata = $data->getRole($_REQUEST['rolename']);
@@ -152,33 +152,32 @@
 		if ($roledata->recordCount() > 0) {
 			$server_info = $misc->getServerInfo();
 			$canRename = $data->hasUserRename() && ($_REQUEST['rolename'] != $server_info['username']);
-			$roledata->f['rolsuper'] = $data->phpBool($roledata->f['rolsuper']);
-			$roledata->f['rolcreatedb'] = $data->phpBool($roledata->f['rolcreatedb']);
-			$roledata->f['rolcreaterole'] = $data->phpBool($roledata->f['rolcreaterole']);
-			$roledata->f['rolinherit'] = $data->phpBool($roledata->f['rolinherit']);
-			$roledata->f['rolcanlogin'] = $data->phpBool($roledata->f['rolcanlogin']);
+			$roledata->fields['rolsuper'] = $data->phpBool($roledata->fields['rolsuper']);
+			$roledata->fields['rolcreatedb'] = $data->phpBool($roledata->fields['rolcreatedb']);
+			$roledata->fields['rolcreaterole'] = $data->phpBool($roledata->fields['rolcreaterole']);
+			$roledata->fields['rolinherit'] = $data->phpBool($roledata->fields['rolinherit']);
+			$roledata->fields['rolcanlogin'] = $data->phpBool($roledata->fields['rolcanlogin']);
 
 			if (!isset($_POST['formExpires'])){
-				if ($canRename) $_POST['formNewRoleName'] = $roledata->f['rolname'];
-				if ($roledata->f['rolsuper']) $_POST['formSuper'] = '';
-				if ($roledata->f['rolcreatedb']) $_POST['formCreateDB'] = '';
-				if ($roledata->f['rolcreaterole']) $_POST['formCreateRole'] = '';
-				if ($roledata->f['rolinherit']) $_POST['formInherits'] = '';
-				if ($roledata->f['rolcanlogin']) $_POST['formCanLogin'] = '';
-				$_POST['formConnLimit'] = $roledata->f['rolconnlimit'] == '-1' ? '' : $roledata->f['rolconnlimit'];
-				$_POST['formExpires'] = $roledata->f['rolvaliduntil'] == 'infinity' ? '' : $roledata->f['rolvaliduntil'];
+				if ($canRename) $_POST['formNewRoleName'] = $roledata->fields['rolname'];
+				if ($roledata->fields['rolsuper']) $_POST['formSuper'] = '';
+				if ($roledata->fields['rolcreatedb']) $_POST['formCreateDB'] = '';
+				if ($roledata->fields['rolcreaterole']) $_POST['formCreateRole'] = '';
+				if ($roledata->fields['rolinherit']) $_POST['formInherits'] = '';
+				if ($roledata->fields['rolcanlogin']) $_POST['formCanLogin'] = '';
+				$_POST['formConnLimit'] = $roledata->fields['rolconnlimit'] == '-1' ? '' : $roledata->fields['rolconnlimit'];
+				$_POST['formExpires'] = $roledata->fields['rolvaliduntil'] == 'infinity' ? '' : $roledata->fields['rolvaliduntil'];
 				$_POST['formPassword'] = '';
 			}
 		
 			echo "<form action=\"roles.php\" method=\"post\">\n";
-			echo $misc->form;
 			echo "<table>\n";
-			echo "\t<tr>\n\t\t<th class=\"data left\" width=\"130\">{$lang['strrolename']}</th>\n";
-			echo "\t\t<td class=\"data1\">", ($canRename ? "<input name=\"formNewRoleName\" size=\"15\" maxlength=\"15\" value=\"" . htmlspecialchars($_POST['formNewRoleName']) . "\" />" : $misc->printVal($roledata->f['rolname'])), "</td>\n\t</tr>\n";
+			echo "\t<tr>\n\t\t<th class=\"data left\" style=\"width: 130px\">{$lang['strname']}</th>\n";
+			echo "\t\t<td class=\"data1\">", ($canRename ? "<input name=\"formNewRoleName\" size=\"15\" maxlength=\"{$data->_maxNameLen}\" value=\"" . htmlspecialchars($_POST['formNewRoleName']) . "\" />" : $misc->printVal($roledata->fields['rolname'])), "</td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strpassword']}</th>\n";
-			echo "\t\t<td class=\"data1\"><input type=\"password\" size=\"15\" maxlength=\"32\" name=\"formPassword\" value=\"", htmlspecialchars($_POST['formPassword']), "\" /></td>\n\t</tr>\n";
+			echo "\t\t<td class=\"data1\"><input type=\"password\" size=\"15\" name=\"formPassword\" value=\"", htmlspecialchars($_POST['formPassword']), "\" /></td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strconfirm']}</th>\n";
-			echo "\t\t<td class=\"data1\"><input type=\"password\" size=\"15\" maxlength=\"32\" name=\"formConfirm\" value=\"\" /></td>\n\t</tr>\n";
+			echo "\t\t<td class=\"data1\"><input type=\"password\" size=\"15\" name=\"formConfirm\" value=\"\" /></td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left\"><label for=\"formSuper\">{$lang['strsuper']}</label></th>\n";
 			echo "\t\t<td class=\"data1\"><input type=\"checkbox\" id=\"formSuper\" name=\"formSuper\"", 
 				(isset($_POST['formSuper'])) ? ' checked="checked"' : '', " /></td>\n\t</tr>\n";
@@ -195,9 +194,9 @@
 			echo "\t\t<td class=\"data1\"><input type=\"checkbox\" id=\"formCanLogin\" name=\"formCanLogin\"", 
 				(isset($_POST['formCanLogin'])) ? ' checked="checked"' : '', " /></td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strconnlimit']}</th>\n";
-			echo "\t\t<td class=\"data1\"><input size=\"4\" maxlength=\"4\" name=\"formConnLimit\" value=\"", htmlspecialchars($_POST['formConnLimit']), "\" /></td>\n\t</tr>\n";
+			echo "\t\t<td class=\"data1\"><input size=\"4\" name=\"formConnLimit\" value=\"", htmlspecialchars($_POST['formConnLimit']), "\" /></td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left\">{$lang['strexpires']}</th>\n";
-			echo "\t\t<td class=\"data1\"><input size=\"23\" maxlength=\"60\" name=\"formExpires\" value=\"", htmlspecialchars($_POST['formExpires']), "\" /></td>\n\t</tr>\n";
+			echo "\t\t<td class=\"data1\"><input size=\"23\" name=\"formExpires\" value=\"", htmlspecialchars($_POST['formExpires']), "\" /></td>\n\t</tr>\n";
 
 			if (!isset($_POST['memberof']))
 			{
@@ -205,7 +204,7 @@
 				if ($memberof->recordCount() > 0) {
 					$i = 0;
 					while (!$memberof->EOF) {
-						$_POST['memberof'][$i++] = $memberof->f['rolname'];
+						$_POST['memberof'][$i++] = $memberof->fields['rolname'];
 						$memberof->moveNext();
 					}
 				}
@@ -219,7 +218,7 @@
 				if ($members->recordCount() > 0) {
 					$i = 0;
 					while (!$members->EOF) {
-						$_POST['members'][$i++] = $members->f['rolname'];
+						$_POST['members'][$i++] = $members->fields['rolname'];
 						$members->moveNext();
 					}
 				}
@@ -233,7 +232,7 @@
 				if ($adminmembers->recordCount() > 0) {
 					$i = 0;
 					while (!$adminmembers->EOF) {
-						$_POST['adminmembers'][$i++] = $adminmembers->f['rolname'];
+						$_POST['adminmembers'][$i++] = $adminmembers->fields['rolname'];
 						$adminmembers->moveNext();
 					}
 				}
@@ -248,7 +247,7 @@
 				echo "\t\t<td class=\"data\">\n";
 				echo "\t\t\t<select name=\"memberof[]\" multiple=\"multiple\" size=\"", min(20, $roles->recordCount()), "\">\n";
 				while (!$roles->EOF) {
-					$rolename = $roles->f['rolname'];
+					$rolename = $roles->fields['rolname'];
 					echo "\t\t\t\t<option value=\"{$rolename}\"",
 					(in_array($rolename, $_POST['memberof']) ? ' selected="selected"' : ''), ">", $misc->printVal($rolename), "</option>\n";
 					$roles->moveNext();
@@ -261,7 +260,7 @@
 				echo "\t\t<td class=\"data\">\n";
 				echo "\t\t\t<select name=\"members[]\" multiple=\"multiple\" size=\"", min(20, $roles->recordCount()), "\">\n";
 				while (!$roles->EOF) {
-					$rolename = $roles->f['rolname'];
+					$rolename = $roles->fields['rolname'];
 					echo "\t\t\t\t<option value=\"{$rolename}\"",
 					(in_array($rolename, $_POST['members']) ? ' selected="selected"' : ''), ">", $misc->printVal($rolename), "</option>\n";
 					$roles->moveNext();
@@ -274,7 +273,7 @@
 				echo "\t\t<td class=\"data\">\n";
 				echo "\t\t\t<select name=\"adminmembers[]\" multiple=\"multiple\" size=\"", min(20, $roles->recordCount()), "\">\n";
 				while (!$roles->EOF) {
-					$rolename = $roles->f['rolname'];
+					$rolename = $roles->fields['rolname'];
 					echo "\t\t\t\t<option value=\"{$rolename}\"",
 					(in_array($rolename, $_POST['adminmembers']) ? ' selected="selected"' : ''), ">", $misc->printVal($rolename), "</option>\n";
 					$roles->moveNext();
@@ -289,6 +288,7 @@
 			echo "<input type=\"hidden\" name=\"memberofold\" value=\"", isset($_POST['memberofold']) ? $_POST['memberofold'] : htmlspecialchars($memberofold), "\" />\n";
 			echo "<input type=\"hidden\" name=\"membersold\" value=\"", isset($_POST['membersold']) ? $_POST['membersold'] : htmlspecialchars($membersold), "\" />\n";
 			echo "<input type=\"hidden\" name=\"adminmembersold\" value=\"", isset($_POST['adminmembersold']) ? $_POST['adminmembersold'] : htmlspecialchars($adminmembersold), "\" />\n";
+			echo $misc->form;
 			echo "<input type=\"submit\" name=\"alter\" value=\"{$lang['stralter']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 			echo "</form>\n";
@@ -315,9 +315,9 @@
 			if (isset($_POST['formNewRoleName'])) $status = $data->setRenameRole($_POST['rolename'], $_POST['formPassword'], isset($_POST['formSuper']), isset($_POST['formCreateDB']), isset($_POST['formCreateRole']), isset($_POST['formInherits']), isset($_POST['formCanLogin']), $_POST['formConnLimit'], $_POST['formExpires'], $_POST['memberof'], $_POST['members'], $_POST['adminmembers'], $_POST['memberofold'], $_POST['membersold'], $_POST['adminmembersold'], $_POST['formNewRoleName']);
 			else $status = $data->setRole($_POST['rolename'], $_POST['formPassword'], isset($_POST['formSuper']), isset($_POST['formCreateDB']), isset($_POST['formCreateRole']), isset($_POST['formInherits']), isset($_POST['formCanLogin']), $_POST['formConnLimit'], $_POST['formExpires'], $_POST['memberof'], $_POST['members'], $_POST['adminmembers'], $_POST['memberofold'], $_POST['membersold'], $_POST['adminmembersold']);
 			if ($status == 0)
-				doDefault($lang['strroleupdated']);
+				doDefault($lang['strrolealtered']);
 			else
-				doAlter($lang['strroleupdatedbad']);
+				doAlter($lang['strrolealteredbad']);
 		}
 	}
 
@@ -335,11 +335,11 @@
 			echo "<p>", sprintf($lang['strconfdroprole'], $misc->printVal($_REQUEST['rolename'])), "</p>\n";	
 			
 			echo "<form action=\"roles.php\" method=\"post\">\n";
-			echo $misc->form;
-			echo "<input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
+			echo "<p><input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
 			echo "<input type=\"hidden\" name=\"rolename\" value=\"", htmlspecialchars($_REQUEST['rolename']), "\" />\n";
+			echo $misc->form;
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
-			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
+			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 			echo "</form>\n";
 		}
 		else {
@@ -364,39 +364,39 @@
 			
 		$roledata = $data->getRole($_REQUEST['rolename']);
 		if($roledata->recordCount() > 0 ) {
-			$roledata->f['rolsuper'] = $data->phpBool($roledata->f['rolsuper']);
-			$roledata->f['rolcreatedb'] = $data->phpBool($roledata->f['rolcreatedb']);
-			$roledata->f['rolcreaterole'] = $data->phpBool($roledata->f['rolcreaterole']);
-			$roledata->f['rolinherit'] = $data->phpBool($roledata->f['rolinherit']);
-			$roledata->f['rolcanlogin'] = $data->phpBool($roledata->f['rolcanlogin']);
+			$roledata->fields['rolsuper'] = $data->phpBool($roledata->fields['rolsuper']);
+			$roledata->fields['rolcreatedb'] = $data->phpBool($roledata->fields['rolcreatedb']);
+			$roledata->fields['rolcreaterole'] = $data->phpBool($roledata->fields['rolcreaterole']);
+			$roledata->fields['rolinherit'] = $data->phpBool($roledata->fields['rolinherit']);
+			$roledata->fields['rolcanlogin'] = $data->phpBool($roledata->fields['rolcanlogin']);
 
 			echo "<table>\n";
-			echo "\t<tr>\n\t\t<th class=\"data\" width=\"130\">Description</th>\n";
-			echo "\t\t<th class=\"data\" width=\"120\">Value</th>\n\t</tr>\n";
-			echo "\t<tr>\n\t\t<td class=\"data1\">{$lang['strrolename']}</td>\n";
+			echo "\t<tr>\n\t\t<th class=\"data\" style=\"width: 130px\">Description</th>\n";
+			echo "\t\t<th class=\"data\" style=\"width: 120\">Value</th>\n\t</tr>\n";
+			echo "\t<tr>\n\t\t<td class=\"data1\">{$lang['strname']}</td>\n";
 			echo "\t\t<td class=\"data1\">", htmlspecialchars($_REQUEST['rolename']), "</td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<td class=\"data2\">{$lang['strsuper']}</td>\n";
-			echo "\t\t<td class=\"data2\">", (($roledata->f['rolsuper']) ? $lang['stryes'] : $lang['strno']), "</td>\n\t</tr>\n";
+			echo "\t\t<td class=\"data2\">", (($roledata->fields['rolsuper']) ? $lang['stryes'] : $lang['strno']), "</td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<td class=\"data1\">{$lang['strcreatedb']}</td>\n";
-			echo "\t\t<td class=\"data1\">", (($roledata->f['rolcreatedb']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
+			echo "\t\t<td class=\"data1\">", (($roledata->fields['rolcreatedb']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
 			echo "\t<tr>\n\t\t<td class=\"data2\">{$lang['strcancreaterole']}</td>\n";
-			echo "\t\t<td class=\"data2\">", (($roledata->f['rolcreaterole']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
+			echo "\t\t<td class=\"data2\">", (($roledata->fields['rolcreaterole']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
 			echo "\t<tr>\n\t\t<td class=\"data1\">{$lang['strinheritsprivs']}</td>\n";
-			echo "\t\t<td class=\"data1\">", (($roledata->f['rolinherit']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
+			echo "\t\t<td class=\"data1\">", (($roledata->fields['rolinherit']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
 			echo "\t<tr>\n\t\t<td class=\"data2\">{$lang['strcanlogin']}</td>\n";
-			echo "\t\t<td class=\"data2\">", (($roledata->f['rolcanlogin']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
+			echo "\t\t<td class=\"data2\">", (($roledata->fields['rolcanlogin']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
 			echo "\t<tr>\n\t\t<td class=\"data1\">{$lang['strconnlimit']}</td>\n";
-			echo "\t\t<td class=\"data1\">", ($roledata->f['rolconnlimit'] == '-1' ? $lang['strnolimit'] : $misc->printVal($roledata->f['rolconnlimit'])), "</td>\n";
+			echo "\t\t<td class=\"data1\">", ($roledata->fields['rolconnlimit'] == '-1' ? $lang['strnolimit'] : $misc->printVal($roledata->fields['rolconnlimit'])), "</td>\n";
 			echo "\t<tr>\n\t\t<td class=\"data2\">{$lang['strexpires']}</td>\n";
-			echo "\t\t<td class=\"data2\">", ($roledata->f['rolvaliduntil'] == 'infinity' ? $lang['strnever'] : $misc->printVal($roledata->f['rolvaliduntil'])), "</td>\n";
+			echo "\t\t<td class=\"data2\">", ($roledata->fields['rolvaliduntil'] == 'infinity' || is_null($roledata->fields['rolvaliduntil']) ? $lang['strnever'] : $misc->printVal($roledata->fields['rolvaliduntil'])), "</td>\n";
 			echo "\t<tr>\n\t\t<td class=\"data1\">{$lang['strsessiondefaults']}</td>\n";
-			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->f['rolconfig']), "</td>\n";
+			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->fields['rolconfig']), "</td>\n";
 			echo "\t<tr>\n\t\t<td class=\"data2\">{$lang['strmemberof']}</td>\n";
 			echo "\t\t<td class=\"data2\">";
 			$memberof = $data->getMemberOf($_REQUEST['rolename']);
 			if ($memberof->recordCount() > 0) {	
 				while (!$memberof->EOF) {
-					echo $misc->printVal($memberof->f['rolname']), "<br />\n";
+					echo $misc->printVal($memberof->fields['rolname']), "<br />\n";
 					$memberof->moveNext();
 				}
 			}
@@ -406,7 +406,7 @@
 			$members = $data->getMembers($_REQUEST['rolename']);
 			if ($members->recordCount() > 0) {
 				while (!$members->EOF) {
-					echo $misc->printVal($members->f['rolname']), "<br />\n";
+					echo $misc->printVal($members->fields['rolname']), "<br />\n";
 					$members->moveNext();
 				}
 			}
@@ -416,7 +416,7 @@
 			$adminmembers = $data->getMembers($_REQUEST['rolename'], 't');
 			if ($adminmembers->recordCount() > 0) {
 				while (!$adminmembers->EOF) {
-					echo $misc->printVal($adminmembers->f['rolname']), "<br />\n";
+					echo $misc->printVal($adminmembers->fields['rolname']), "<br />\n";
 					$adminmembers->moveNext();
 				}
 			}
@@ -425,11 +425,11 @@
 		}
 		else echo "<p>{$lang['strnodata']}</p>\n";
 
-		echo "<p><a class=\"navlink\" href=\"roles.php?{$misc->href}\">{$lang['strshowallroles']}</a> |\n";
-		echo "<a class=\"navlink\" href=\"roles.php?action=alter&amp;{$misc->href}&amp;rolename=", 
-			urlencode($_REQUEST['rolename']), "\">{$lang['stralter']}</a> |\n";
-		echo "<a class=\"navlink\" href=\"roles.php?action=confirm_drop&amp;{$misc->href}&amp;rolename=",
-			urlencode($_REQUEST['rolename']), "\">{$lang['strdrop']}</a>\n";
+		echo "<ul class=\"navlink\">\n\t<li><a href=\"roles.php?{$misc->href}\">{$lang['strshowallroles']}</a></li>\n";
+		echo "\t<li><a href=\"roles.php?action=alter&amp;{$misc->href}&amp;rolename=", 
+			urlencode($_REQUEST['rolename']), "\">{$lang['stralter']}</a></li>\n";
+		echo "\t<li><a href=\"roles.php?action=confirm_drop&amp;{$misc->href}&amp;rolename=",
+			urlencode($_REQUEST['rolename']), "\">{$lang['strdrop']}</li>\n</ul>\n";
 	}
 
 	/**
@@ -452,12 +452,12 @@
 		$misc->printMsg($msg);
 
 		if ($roledata->recordCount() > 0) {
-			$roledata->f['rolsuper'] = $data->phpBool($roledata->f['rolsuper']);
-			$roledata->f['rolcreatedb'] = $data->phpBool($roledata->f['rolcreatedb']);
-			$roledata->f['rolcreaterole'] = $data->phpBool($roledata->f['rolcreaterole']);
-			$roledata->f['rolinherit'] = $data->phpBool($roledata->f['rolinherit']);
+			$roledata->fields['rolsuper'] = $data->phpBool($roledata->fields['rolsuper']);
+			$roledata->fields['rolcreatedb'] = $data->phpBool($roledata->fields['rolcreatedb']);
+			$roledata->fields['rolcreaterole'] = $data->phpBool($roledata->fields['rolcreaterole']);
+			$roledata->fields['rolinherit'] = $data->phpBool($roledata->fields['rolinherit']);
 			echo "<table>\n";
-			echo "\t<tr>\n\t\t<th class=\"data\">{$lang['strrolename']}</th>\n";
+			echo "\t<tr>\n\t\t<th class=\"data\">{$lang['strname']}</th>\n";
 			echo "\t\t<th class=\"data\">{$lang['strsuper']}</th>\n";
 			echo "\t\t<th class=\"data\">{$lang['strcreatedb']}</th>\n";
 			echo "\t\t<th class=\"data\">{$lang['strcancreaterole']}</th>\n";
@@ -466,14 +466,14 @@
 			echo "\t\t<th class=\"data\">{$lang['strexpires']}</th>\n";
 			echo "\t\t<th class=\"data\">{$lang['strsessiondefaults']}</th>\n";
 			echo "\t</tr>\n";
-			echo "\t<tr>\n\t\t<td class=\"data1\">", $misc->printVal($roledata->f['rolname']), "</td>\n";
-			echo "\t\t<td class=\"data1\" id=\"center\">", (($roledata->f['rolsuper']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
-			echo "\t\t<td class=\"data1\" id=\"center\">", (($roledata->f['rolcreatedb']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
-			echo "\t\t<td class=\"data1\" id=\"center\">", (($roledata->f['rolcreaterole']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
-			echo "\t\t<td class=\"data1\" id=\"center\">", (($roledata->f['rolinherit']) ? $lang['stryes'] : $lang['strno']), "</td>\n";
-			echo "\t\t<td class=\"data1\" id=\"center\">", ($roledata->f['rolconnlimit'] == '-1' ? $lang['strnolimit'] : $misc->printVal($roledata->f['rolconnlimit'])), "</td>\n";
-			echo "\t\t<td class=\"data1\">", ($roledata->f['rolvaliduntil'] == 'infinity' ? $lang['strnever'] : $misc->printVal($roledata->f['rolvaliduntil'])), "</td>\n";
-			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->f['rolconfig']), "</td>\n";
+			echo "\t<tr>\n\t\t<td class=\"data1\">", $misc->printVal($roledata->fields['rolname']), "</td>\n";
+			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->fields['rolsuper'], 'yesno'), "</td>\n";
+			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->fields['rolcreatedb'], 'yesno'), "</td>\n";
+			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->fields['rolcreaterole'], 'yesno'), "</td>\n";
+			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->fields['rolinherit'], 'yesno'), "</td>\n";
+			echo "\t\t<td class=\"data1\">", ($roledata->fields['rolconnlimit'] == '-1' ? $lang['strnolimit'] : $misc->printVal($roledata->fields['rolconnlimit'])), "</td>\n";
+			echo "\t\t<td class=\"data1\">", ($roledata->fields['rolvaliduntil'] == 'infinity' || is_null($roledata->fields['rolvaliduntil']) ? $lang['strnever'] : $misc->printVal($roledata->fields['rolvaliduntil'])), "</td>\n";
+			echo "\t\t<td class=\"data1\">", $misc->printVal($roledata->fields['rolconfig']), "</td>\n";
 			echo "\t</tr>\n</table>\n";
 		}
 		else echo "<p>{$lang['strnodata']}</p>\n";
@@ -500,15 +500,15 @@
 			if (!isset($_POST['confirm'])) $_POST['confirm'] = '';
 			
 			echo "<form action=\"roles.php\" method=\"post\">\n";
-			echo $misc->form;
 			echo "<table>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strpassword']}</th>\n";
 			echo "\t\t<td><input type=\"password\" name=\"password\" size=\"32\" value=\"", 
 				htmlspecialchars($_POST['password']), "\" /></td>\n\t</tr>\n";
 			echo "\t<tr>\n\t\t<th class=\"data left required\">{$lang['strconfirm']}</th>\n";
 			echo "\t\t<td><input type=\"password\" name=\"confirm\" size=\"32\" value=\"\" /></td>\n\t</tr>\n";
-			echo "<table>\n";
+			echo "</table>\n";
 			echo "<p><input type=\"hidden\" name=\"action\" value=\"changepassword\" />\n";
+			echo $misc->form;
 			echo "<input type=\"submit\" name=\"ok\" value=\"{$lang['strok']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
 			echo "</p></form>\n";
@@ -539,11 +539,13 @@
 		global $lang;
 		
 		function renderRoleConnLimit($val) {
-			return $val == '-1' ? 'No limit' : htmlspecialchars($val);
+			global $lang;
+			return $val == '-1' ? $lang['strnolimit'] : htmlspecialchars($val);
  		}
 		
 		function renderRoleExpires($val) {
-			return $val == 'infinity' ? 'Never' : htmlspecialchars($val);
+			global $lang;
+			return $val == 'infinity' ? $lang['strnever'] : htmlspecialchars($val);
  		}
 		
 		$misc->printTrail('server');
@@ -553,40 +555,48 @@
 		$roles = $data->getRoles();
 		
 		$columns = array(
-			'rolename' => array(
-				'title' => $lang['strrolename'],
-				'field' => 'rolname',
+			'role' => array(
+				'title' => $lang['strrole'],
+				'field' => field('rolname'),
+				'url'   => "redirect.php?subject=role&amp;action=properties&amp;{$misc->href}&amp;",
+				'vars'  => array('rolename' => 'rolname'),
 			),
 			'superuser' => array(
 				'title' => $lang['strsuper'],
-				'field' => 'rolsuper',
+				'field' => field('rolsuper'),
 				'type'  => 'yesno',
 			),
 			'createdb' => array(
 				'title' => $lang['strcreatedb'],
-				'field' => 'rolcreatedb',
+				'field' => field('rolcreatedb'),
 				'type'  => 'yesno',
 			),
 			'createrole' => array(
 				'title' => $lang['strcancreaterole'],
-				'field' => 'rolcreaterole',
+				'field' => field('rolcreaterole'),
 				'type'  => 'yesno',
 			),
 			'inherits' => array(
 				'title' => $lang['strinheritsprivs'],
-				'field' => 'rolinherit',
+				'field' => field('rolinherit'),
 				'type'  => 'yesno',
 			),
 			'canloging' => array(
 				'title' => $lang['strcanlogin'],
-				'field' => 'rolcanlogin',
+				'field' => field('rolcanlogin'),
 				'type'  => 'yesno',
 			),
+			'connlimit' => array(
+				'title'	=> $lang['strconnlimit'],
+				'field'	=> field('rolconnlimit'),
+				'type'	=> 'callback',
+				'params'=> array('function' => 'renderRoleConnLimit')
+			),
 			'expires' => array(
 				'title' => $lang['strexpires'],
-				'field' => 'rolvaliduntil',
+				'field' => field('rolvaliduntil'),
 				'type'  => 'callback',
-				'params'=> array('function' => 'renderRoleExpires'),
+				'params'=> array('function' => 'renderRoleExpires', 'null' => $lang['strnever']),
 			),
 			'actions' => array(
 				'title' => $lang['stractions'],
@@ -594,11 +604,6 @@
 		);
 		
 		$actions = array(
-			'properties' => array(
-				'title' => $lang['strproperties'],
-				'url'   => "redirect.php?subject=role&amp;action=properties&amp;{$misc->href}&amp;",
-				'vars'  => array('rolename' => 'rolname'),
-			),		
 			'alter' => array(
 				'title' => $lang['stralter'],
 				'url'   => "roles.php?action=alter&amp;{$misc->href}&amp;",
